<?php
/**
 * Plugin Name: Advanced Effective Slider
 * Description: Advanced Effective Slider plugin for Elementor with 21+ pre-build responsive and modern slider designs.
 * Plugin URI:  https://bwdplugins.com/plugins/advanced-effective-slider
 * Version:     1.0
 * Author:      Best WP Developer
 * Author URI:  https://bestwpdeveloper.com/advanced-slider
 * Text Domain: bwdads-swiper-td
 * Elementor tested up to: 3.0.0
 * Elementor Pro tested up to: 3.7.3
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly
require_once ( plugin_dir_path(__FILE__) ) . '/includes/bwdads-plugin-activition.php';
final class bwdads_swiper_slider{

	const VERSION = '1.3';

	const MINIMUM_ELEMENTOR_VERSION = '3.0.0';

	const MINIMUM_PHP_VERSION = '7.0';

	public function __construct() {
		// Load translation
		add_action( 'bwdads_init', array( $this, 'bwdads_loaded_textdomain' ) );
		// bwdads_init Plugin
		add_action( 'plugins_loaded', array( $this, 'bwdads_init' ) );
	}

	public function bwdads_loaded_textdomain() {
		load_plugin_textdomain( 'bwdads-swiper-td' );
	}

	public function bwdads_init() {
		// Check if Elementor installed and activated
		if ( ! did_action( 'elementor/loaded' ) ) {
			add_action( 'admin_notices', 'bwdads_addon_failed_load');
			return;
		}

		// Check for required Elementor version
		if ( ! version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
			add_action( 'admin_notices', array( $this, 'bwdads_admin_notice_minimum_elementor_version' ) );
			return;
		}

		// Check for required PHP version
		if ( version_compare( PHP_VERSION, self::MINIMUM_PHP_VERSION, '<' ) ) {
			add_action( 'admin_notices', array( $this, 'bwdads_admin_notice_minimum_php_version' ) );
			return;
		}

		// Once we get here, We have passed all validation checks so we can safely include our plugin
		require_once( 'bwdads-slider-boots.php' );
	}

	public function bwdads_admin_notice_minimum_elementor_version() {
		if ( isset( $_GET['activate'] ) ) {
			unset( $_GET['activate'] );
		}

		$message = sprintf(
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'bwdads-swiper-td' ),
			'<strong>' . esc_html__( 'Advanced Effective Slider', 'bwdads-swiper-td' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'bwdads-swiper-td' ) . '</strong>',
			self::MINIMUM_ELEMENTOR_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>' . esc_html__('%1$s', 'bwdads-swiper-td') . '</p></div>', $message );
	}

	public function bwdads_admin_notice_minimum_php_version() {
		if ( isset( $_GET['activate'] ) ) {
			unset( $_GET['activate'] );
		}

		$message = sprintf(
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'bwdads-swiper-td' ),
			'<strong>' . esc_html__( 'Advanced Effective Slider', 'bwdads-swiper-td' ) . '</strong>',
			'<strong>' . esc_html__( 'PHP', 'bwdads-swiper-td' ) . '</strong>',
			self::MINIMUM_PHP_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>' . esc_html__('%1$s', 'bwdads-swiper-td') . '</p></div>', $message );
	}
}

// Instantiate slider.
new bwdads_swiper_slider();
remove_action( 'shutdown', 'wp_ob_end_flush_all', 1 );